@@ -257,7 +257,7 @@ bus_driver_send_service_owner_changed (const char     *service_name,
 
   _dbus_assert (dbus_message_has_signature (message, "sss"));
 
-  if (!bus_transaction_capture (transaction, NULL, message))
+  if (!bus_transaction_capture (transaction, NULL, NULL, message))
     goto oom;
 
   retval = bus_dispatch_matches (transaction, NULL, NULL, message, error);
@@ -1026,7 +1026,7 @@ bus_driver_send_or_activate (BusTransaction *transaction,
 
       activation = bus_context_get_activation (context);
 
-      if (!bus_transaction_capture (transaction, NULL, message))
+      if (!bus_transaction_capture (transaction, NULL, NULL, message))
         {
           BUS_SET_OOM (error);
           _dbus_verbose ("No memory for bus_transaction_capture()");
